var group__PkgNumberTypesRef =
[
    [ "Concepts", "group__PkgNumberTypesConcepts.html", "group__PkgNumberTypesConcepts" ],
    [ "Built-in types", "group__nt__builtin.html", "group__nt__builtin" ],
    [ "CORE", "group__nt__core.html", "group__nt__core" ],
    [ "Boost", "group__nt__boost.html", "group__nt__boost" ],
    [ "LEDA", "group__nt__leda.html", "group__nt__leda" ],
    [ "GMP", "group__nt__gmp.html", "group__nt__gmp" ],
    [ "CGAL Number Types", "group__nt__cgal.html", "group__nt__cgal" ],
    [ "Relates Rational", "group__nt__rrational.html", "group__nt__rrational" ],
    [ "Relates Algebraic Extensions", "group__nt__ralgebraic.html", "group__nt__ralgebraic" ],
    [ "Utilities", "group__nt__util.html", "group__nt__util" ],
    [ "CGAL_PI", "group__PkgNumberTypesRef.html#gaad1ab6a12affa6daba8724bd40523753", null ]
];